/****************************************************************************
** Meta object code from reading C++ file 'qtexttospeechengine.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtspeech/src/tts/qtexttospeechengine.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtexttospeechengine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19QTextToSpeechEngineE_t {};
} // unnamed namespace

template <> constexpr inline auto QTextToSpeechEngine::qt_create_metaobjectdata<qt_meta_tag_ZN19QTextToSpeechEngineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QTextToSpeechEngine",
        "stateChanged",
        "",
        "QTextToSpeech::State",
        "state",
        "errorOccurred",
        "QTextToSpeech::ErrorReason",
        "error",
        "errorString",
        "sayingWord",
        "word",
        "qsizetype",
        "start",
        "length",
        "synthesized",
        "QAudioFormat",
        "format",
        "data"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(QTextToSpeech::State)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(QTextToSpeech::ErrorReason, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'sayingWord'
        QtMocHelpers::SignalData<void(const QString &, qsizetype, qsizetype)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 11, 13 },
        }}),
        // Signal 'synthesized'
        QtMocHelpers::SignalData<void(const QAudioFormat &, const QByteArray &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QByteArray, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QTextToSpeechEngine, qt_meta_tag_ZN19QTextToSpeechEngineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QTextToSpeechEngine::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QTextToSpeechEngineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QTextToSpeechEngineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QTextToSpeechEngineE_t>.metaTypes,
    nullptr
} };

void QTextToSpeechEngine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QTextToSpeechEngine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<QTextToSpeech::State>>(_a[1]))); break;
        case 1: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QTextToSpeech::ErrorReason>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->sayingWord((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[3]))); break;
        case 3: _t->synthesized((*reinterpret_cast<std::add_pointer_t<QAudioFormat>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAudioFormat >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeechEngine::*)(QTextToSpeech::State )>(_a, &QTextToSpeechEngine::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeechEngine::*)(QTextToSpeech::ErrorReason , const QString & )>(_a, &QTextToSpeechEngine::errorOccurred, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeechEngine::*)(const QString & , qsizetype , qsizetype )>(_a, &QTextToSpeechEngine::sayingWord, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeechEngine::*)(const QAudioFormat & , const QByteArray & )>(_a, &QTextToSpeechEngine::synthesized, 3))
            return;
    }
}

const QMetaObject *QTextToSpeechEngine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QTextToSpeechEngine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QTextToSpeechEngineE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QTextToSpeechEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QTextToSpeechEngine::stateChanged(QTextToSpeech::State _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QTextToSpeechEngine::errorOccurred(QTextToSpeech::ErrorReason _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void QTextToSpeechEngine::sayingWord(const QString & _t1, qsizetype _t2, qsizetype _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void QTextToSpeechEngine::synthesized(const QAudioFormat & _t1, const QByteArray & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
