/****************************************************************************
** Meta object code from reading C++ file 'qvoice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtspeech/src/tts/qvoice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qvoice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6QVoiceE_t {};
} // unnamed namespace

template <> constexpr inline auto QVoice::qt_create_metaobjectdata<qt_meta_tag_ZN6QVoiceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QVoice",
        "name",
        "gender",
        "Gender",
        "age",
        "Age",
        "locale",
        "language",
        "QLocale::Language",
        "Male",
        "Female",
        "Unknown",
        "Child",
        "Teenager",
        "Adult",
        "Senior",
        "Other"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gender'
        QtMocHelpers::PropertyData<enum Gender>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'age'
        QtMocHelpers::PropertyData<enum Age>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'locale'
        QtMocHelpers::PropertyData<QLocale>(6, QMetaType::QLocale, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'language'
        QtMocHelpers::PropertyData<QLocale::Language>(7, 0x80000000 | 8, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag, -1, 0x606),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Gender'
        QtMocHelpers::EnumData<enum Gender>(3, 3, QMC::EnumFlags{}).add({
            {    9, Gender::Male },
            {   10, Gender::Female },
            {   11, Gender::Unknown },
        }),
        // enum 'Age'
        QtMocHelpers::EnumData<enum Age>(5, 5, QMC::EnumFlags{}).add({
            {   12, Age::Child },
            {   13, Age::Teenager },
            {   14, Age::Adult },
            {   15, Age::Senior },
            {   16, Age::Other },
        }),
    };
    return QtMocHelpers::metaObjectData<QVoice, qt_meta_tag_ZN6QVoiceE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6QVoiceE[] = {
    QMetaObject::SuperData::link<QLocale::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QVoice::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6QVoiceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6QVoiceE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6QVoiceE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6QVoiceE_t>.metaTypes,
    nullptr
} };

void QVoice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QVoice *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<enum Gender*>(_v) = _t->gender(); break;
        case 2: *reinterpret_cast<enum Age*>(_v) = _t->age(); break;
        case 3: *reinterpret_cast<QLocale*>(_v) = _t->locale(); break;
        case 4: *reinterpret_cast<QLocale::Language*>(_v) = _t->language(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
