// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_qtexttospeech_flite.cpp"
#include "EWIEGA46WW/moc_qtexttospeech_flite_plugin.cpp"
#include "EWIEGA46WW/moc_qtexttospeech_flite_processor.cpp"
