/****************************************************************************
** Meta object code from reading C++ file 'qvoiceselectorattached_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../qtspeech/src/tts/qml/qvoiceselectorattached_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qvoiceselectorattached_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22QVoiceSelectorAttachedE_t {};
} // unnamed namespace

template <> constexpr inline auto QVoiceSelectorAttached::qt_create_metaobjectdata<qt_meta_tag_ZN22QVoiceSelectorAttachedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QVoiceSelectorAttached",
        "QML.Element",
        "VoiceSelector",
        "QML.AddedInVersion",
        "1542",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "VoiceSelector is only available via attached properties.",
        "QML.Attached",
        "nameChanged",
        "",
        "genderChanged",
        "ageChanged",
        "localeChanged",
        "languageChanged",
        "select",
        "name",
        "QVariant",
        "gender",
        "QVoice::Gender",
        "age",
        "QVoice::Age",
        "locale",
        "language"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(10, 11, QMC::AccessPublic, QMetaType::Void),
        // Signal 'genderChanged'
        QtMocHelpers::SignalData<void()>(12, 11, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ageChanged'
        QtMocHelpers::SignalData<void()>(13, 11, QMC::AccessPublic, QMetaType::Void),
        // Signal 'localeChanged'
        QtMocHelpers::SignalData<void()>(14, 11, QMC::AccessPublic, QMetaType::Void),
        // Signal 'languageChanged'
        QtMocHelpers::SignalData<void()>(15, 11, QMC::AccessPublic, QMetaType::Void),
        // Slot 'select'
        QtMocHelpers::SlotData<void()>(16, 11, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QVariant>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'gender'
        QtMocHelpers::PropertyData<QVoice::Gender>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'age'
        QtMocHelpers::PropertyData<QVoice::Age>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'locale'
        QtMocHelpers::PropertyData<QLocale>(23, QMetaType::QLocale, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'language'
        QtMocHelpers::PropertyData<QLocale>(24, QMetaType::QLocale, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,    0 },
    });
    return QtMocHelpers::metaObjectData<QVoiceSelectorAttached, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN22QVoiceSelectorAttachedE[] = {
    QMetaObject::SuperData::link<QVoice::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QVoiceSelectorAttached::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QVoiceSelectorAttachedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QVoiceSelectorAttachedE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN22QVoiceSelectorAttachedE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22QVoiceSelectorAttachedE_t>.metaTypes,
    nullptr
} };

void QVoiceSelectorAttached::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QVoiceSelectorAttached *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->genderChanged(); break;
        case 2: _t->ageChanged(); break;
        case 3: _t->localeChanged(); break;
        case 4: _t->languageChanged(); break;
        case 5: _t->select(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QVoiceSelectorAttached::*)()>(_a, &QVoiceSelectorAttached::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVoiceSelectorAttached::*)()>(_a, &QVoiceSelectorAttached::genderChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVoiceSelectorAttached::*)()>(_a, &QVoiceSelectorAttached::ageChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVoiceSelectorAttached::*)()>(_a, &QVoiceSelectorAttached::localeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVoiceSelectorAttached::*)()>(_a, &QVoiceSelectorAttached::languageChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVoice::Age >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVoice::Gender >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QVoice::Gender*>(_v) = _t->gender(); break;
        case 2: *reinterpret_cast<QVoice::Age*>(_v) = _t->age(); break;
        case 3: *reinterpret_cast<QLocale*>(_v) = _t->locale(); break;
        case 4: *reinterpret_cast<QLocale*>(_v) = _t->language(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QVariant*>(_v)); break;
        case 1: _t->setGender(*reinterpret_cast<QVoice::Gender*>(_v)); break;
        case 2: _t->setAge(*reinterpret_cast<QVoice::Age*>(_v)); break;
        case 3: _t->setLocale(*reinterpret_cast<QLocale*>(_v)); break;
        case 4: _t->setLanguage(*reinterpret_cast<QLocale*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QVoiceSelectorAttached::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QVoiceSelectorAttached::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QVoiceSelectorAttachedE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QVoiceSelectorAttached::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QVoiceSelectorAttached::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QVoiceSelectorAttached::genderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QVoiceSelectorAttached::ageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QVoiceSelectorAttached::localeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QVoiceSelectorAttached::languageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
