/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<qdeclarativetexttospeech_p.h>)
#  include <qdeclarativetexttospeech_p.h>
#endif
#if __has_include(<qtexttospeech_qmltypes_p.h>)
#  include <qtexttospeech_qmltypes_p.h>
#endif
#if __has_include(<qvoiceselectorattached_p.h>)
#  include <qvoiceselectorattached_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtTextToSpeech()
{
    qmlRegisterModule("QtTextToSpeech", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QDeclarativeTextToSpeech>("QtTextToSpeech", 6);
    QMetaType::fromType<QTextToSpeech *>().id();
    qmlRegisterEnum<QTextToSpeech::State>("QTextToSpeech::State");
    qmlRegisterEnum<QTextToSpeech::ErrorReason>("QTextToSpeech::ErrorReason");
    qmlRegisterEnum<QTextToSpeech::BoundaryHint>("QTextToSpeech::BoundaryHint");
    qmlRegisterEnum<QTextToSpeech::Capabilities>("QTextToSpeech::Capabilities");
    qmlRegisterEnum<QTextToSpeech::Capability>("QTextToSpeech::Capability");
    qmlRegisterTypesAndRevisions<QVoiceForeign>("QtTextToSpeech", 6);
    QMetaType::fromType<QVoiceForeign *>().id();
    qmlRegisterEnum<QVoice::Gender>("QVoice::Gender");
    qmlRegisterEnum<QVoice::Age>("QVoice::Age");
    QMetaType::fromType<QVoiceDerived>().id();
    qmlRegisterNamespaceAndRevisions(&QVoiceDerived::staticMetaObject, "QtTextToSpeech", 6, nullptr, &QVoiceForeignNamespace::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<QVoiceSelectorAttached>("QtTextToSpeech", 6);
    QT_WARNING_POP
    qmlRegisterModule("QtTextToSpeech", 6, 12);
}

static const QQmlModuleRegistration qtTextToSpeechRegistration("QtTextToSpeech", qml_register_types_QtTextToSpeech);
