/****************************************************************************
** Meta object code from reading C++ file 'qtexttospeech_flite_processor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../qtspeech/src/plugins/tts/flite/qtexttospeech_flite_processor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtexttospeech_flite_processor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27QTextToSpeechProcessorFliteE_t {};
} // unnamed namespace

template <> constexpr inline auto QTextToSpeechProcessorFlite::qt_create_metaobjectdata<qt_meta_tag_ZN27QTextToSpeechProcessorFliteE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QTextToSpeechProcessorFlite",
        "errorOccurred",
        "",
        "QTextToSpeech::ErrorReason",
        "error",
        "errorString",
        "stateChanged",
        "QTextToSpeech::State",
        "sayingWord",
        "word",
        "qsizetype",
        "begin",
        "length",
        "synthesized",
        "QAudioFormat",
        "format",
        "array",
        "say",
        "text",
        "voiceId",
        "pitch",
        "rate",
        "volume",
        "synthesize",
        "pause",
        "QTextToSpeech::BoundaryHint",
        "boundaryHint",
        "resume",
        "stop"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(QTextToSpeech::ErrorReason, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(QTextToSpeech::State)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'sayingWord'
        QtMocHelpers::SignalData<void(const QString &, qsizetype, qsizetype)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 }, { 0x80000000 | 10, 12 },
        }}),
        // Signal 'synthesized'
        QtMocHelpers::SignalData<void(const QAudioFormat &, const QByteArray &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QByteArray, 16 },
        }}),
        // Method 'say'
        QtMocHelpers::MethodData<void(const QString &, int, double, double, double)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::Int, 19 }, { QMetaType::Double, 20 }, { QMetaType::Double, 21 },
            { QMetaType::Double, 22 },
        }}),
        // Method 'synthesize'
        QtMocHelpers::MethodData<void(const QString &, int, double, double, double)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::Int, 19 }, { QMetaType::Double, 20 }, { QMetaType::Double, 21 },
            { QMetaType::Double, 22 },
        }}),
        // Method 'pause'
        QtMocHelpers::MethodData<void(QTextToSpeech::BoundaryHint)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Method 'resume'
        QtMocHelpers::MethodData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'stop'
        QtMocHelpers::MethodData<void(QTextToSpeech::BoundaryHint)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QTextToSpeechProcessorFlite, qt_meta_tag_ZN27QTextToSpeechProcessorFliteE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QTextToSpeechProcessorFlite::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QTextToSpeechProcessorFliteE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QTextToSpeechProcessorFliteE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27QTextToSpeechProcessorFliteE_t>.metaTypes,
    nullptr
} };

void QTextToSpeechProcessorFlite::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QTextToSpeechProcessorFlite *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QTextToSpeech::ErrorReason>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<QTextToSpeech::State>>(_a[1]))); break;
        case 2: _t->sayingWord((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[3]))); break;
        case 3: _t->synthesized((*reinterpret_cast<std::add_pointer_t<QAudioFormat>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 4: _t->say((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5]))); break;
        case 5: _t->synthesize((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5]))); break;
        case 6: _t->pause((*reinterpret_cast<std::add_pointer_t<QTextToSpeech::BoundaryHint>>(_a[1]))); break;
        case 7: _t->resume(); break;
        case 8: _t->stop((*reinterpret_cast<std::add_pointer_t<QTextToSpeech::BoundaryHint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAudioFormat >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeechProcessorFlite::*)(QTextToSpeech::ErrorReason , const QString & )>(_a, &QTextToSpeechProcessorFlite::errorOccurred, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeechProcessorFlite::*)(QTextToSpeech::State )>(_a, &QTextToSpeechProcessorFlite::stateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeechProcessorFlite::*)(const QString & , qsizetype , qsizetype )>(_a, &QTextToSpeechProcessorFlite::sayingWord, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeechProcessorFlite::*)(const QAudioFormat & , const QByteArray & )>(_a, &QTextToSpeechProcessorFlite::synthesized, 3))
            return;
    }
}

const QMetaObject *QTextToSpeechProcessorFlite::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QTextToSpeechProcessorFlite::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QTextToSpeechProcessorFliteE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QTextToSpeechProcessorFlite::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void QTextToSpeechProcessorFlite::errorOccurred(QTextToSpeech::ErrorReason _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void QTextToSpeechProcessorFlite::stateChanged(QTextToSpeech::State _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QTextToSpeechProcessorFlite::sayingWord(const QString & _t1, qsizetype _t2, qsizetype _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void QTextToSpeechProcessorFlite::synthesized(const QAudioFormat & _t1, const QByteArray & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
