/****************************************************************************
** Meta object code from reading C++ file 'qtexttospeech.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtspeech/src/tts/qtexttospeech.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtexttospeech.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QTextToSpeechE_t {};
} // unnamed namespace

template <> constexpr inline auto QTextToSpeech::qt_create_metaobjectdata<qt_meta_tag_ZN13QTextToSpeechE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QTextToSpeech",
        "engineChanged",
        "",
        "engine",
        "stateChanged",
        "QTextToSpeech::State",
        "state",
        "errorOccurred",
        "QTextToSpeech::ErrorReason",
        "error",
        "errorString",
        "localeChanged",
        "locale",
        "rateChanged",
        "rate",
        "pitchChanged",
        "pitch",
        "volumeChanged",
        "volume",
        "voiceChanged",
        "QVoice",
        "voice",
        "sayingWord",
        "word",
        "qsizetype",
        "id",
        "start",
        "length",
        "aboutToSynthesize",
        "say",
        "text",
        "enqueue",
        "stop",
        "QTextToSpeech::BoundaryHint",
        "boundaryHint",
        "pause",
        "resume",
        "setLocale",
        "setRate",
        "setPitch",
        "setVolume",
        "setVoice",
        "setEngine",
        "QVariantMap",
        "params",
        "errorReason",
        "availableLocales",
        "QList<QLocale>",
        "availableVoices",
        "QList<QVoice>",
        "availableEngines",
        "State",
        "engineCapabilities",
        "Capabilities",
        "Ready",
        "Speaking",
        "Paused",
        "Error",
        "Synthesizing",
        "ErrorReason",
        "NoError",
        "Initialization",
        "Configuration",
        "Input",
        "Playback",
        "BoundaryHint",
        "Default",
        "Immediate",
        "Word",
        "Sentence",
        "Utterance",
        "Capability",
        "None",
        "Speak",
        "PauseResume",
        "WordByWordProgress",
        "Synthesize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'engineChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(QTextToSpeech::State)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(QTextToSpeech::ErrorReason, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'localeChanged'
        QtMocHelpers::SignalData<void(const QLocale &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QLocale, 12 },
        }}),
        // Signal 'rateChanged'
        QtMocHelpers::SignalData<void(double)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 14 },
        }}),
        // Signal 'pitchChanged'
        QtMocHelpers::SignalData<void(double)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 16 },
        }}),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void(double)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 18 },
        }}),
        // Signal 'voiceChanged'
        QtMocHelpers::SignalData<void(const QVoice &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'sayingWord'
        QtMocHelpers::SignalData<void(const QString &, qsizetype, qsizetype, qsizetype)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 }, { 0x80000000 | 24, 25 }, { 0x80000000 | 24, 26 }, { 0x80000000 | 24, 27 },
        }}),
        // Signal 'aboutToSynthesize'
        QtMocHelpers::SignalData<void(qsizetype)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'say'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'enqueue'
        QtMocHelpers::SlotData<qsizetype(const QString &)>(31, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'stop'
        QtMocHelpers::SlotData<void(QTextToSpeech::BoundaryHint)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void(QTextToSpeech::BoundaryHint)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'resume'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setLocale'
        QtMocHelpers::SlotData<void(const QLocale &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QLocale, 12 },
        }}),
        // Slot 'setRate'
        QtMocHelpers::SlotData<void(double)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 14 },
        }}),
        // Slot 'setPitch'
        QtMocHelpers::SlotData<void(double)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 16 },
        }}),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(double)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 18 },
        }}),
        // Slot 'setVoice'
        QtMocHelpers::SlotData<void(const QVoice &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'setEngine'
        QtMocHelpers::MethodData<bool(const QString &, const QVariantMap &)>(42, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 43, 44 },
        }}),
        // Method 'setEngine'
        QtMocHelpers::MethodData<bool(const QString &)>(42, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'errorReason'
        QtMocHelpers::MethodData<QTextToSpeech::ErrorReason() const>(45, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Method 'errorString'
        QtMocHelpers::MethodData<QString() const>(10, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'availableLocales'
        QtMocHelpers::MethodData<QList<QLocale>() const>(46, 2, QMC::AccessPublic, 0x80000000 | 47),
        // Method 'availableVoices'
        QtMocHelpers::MethodData<QList<QVoice>() const>(48, 2, QMC::AccessPublic, 0x80000000 | 49),
        // Method 'availableEngines'
        QtMocHelpers::MethodData<QStringList()>(50, 2, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'engine'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(6, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'volume'
        QtMocHelpers::PropertyData<double>(18, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6),
        // property 'rate'
        QtMocHelpers::PropertyData<double>(14, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'pitch'
        QtMocHelpers::PropertyData<double>(16, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'locale'
        QtMocHelpers::PropertyData<QLocale>(12, QMetaType::QLocale, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'voice'
        QtMocHelpers::PropertyData<QVoice>(21, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 7),
        // property 'engineCapabilities'
        QtMocHelpers::PropertyData<Capabilities>(52, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 0, 0x606),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(51, 51, QMC::EnumFlags{}).add({
            {   54, State::Ready },
            {   55, State::Speaking },
            {   56, State::Paused },
            {   57, State::Error },
            {   58, State::Synthesizing },
        }),
        // enum 'ErrorReason'
        QtMocHelpers::EnumData<enum ErrorReason>(59, 59, QMC::EnumIsScoped).add({
            {   60, ErrorReason::NoError },
            {   61, ErrorReason::Initialization },
            {   62, ErrorReason::Configuration },
            {   63, ErrorReason::Input },
            {   64, ErrorReason::Playback },
        }),
        // enum 'BoundaryHint'
        QtMocHelpers::EnumData<enum BoundaryHint>(65, 65, QMC::EnumIsScoped).add({
            {   66, BoundaryHint::Default },
            {   67, BoundaryHint::Immediate },
            {   68, BoundaryHint::Word },
            {   69, BoundaryHint::Sentence },
            {   70, BoundaryHint::Utterance },
        }),
        // flag 'Capabilities'
        QtMocHelpers::EnumData<Capabilities>(53, 71, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {   72, Capability::None },
            {   73, Capability::Speak },
            {   74, Capability::PauseResume },
            {   75, Capability::WordByWordProgress },
            {   76, Capability::Synthesize },
        }),
    };
    return QtMocHelpers::metaObjectData<QTextToSpeech, qt_meta_tag_ZN13QTextToSpeechE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QTextToSpeech::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QTextToSpeechE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QTextToSpeechE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QTextToSpeechE_t>.metaTypes,
    nullptr
} };

void QTextToSpeech::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QTextToSpeech *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->engineChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<QTextToSpeech::State>>(_a[1]))); break;
        case 2: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QTextToSpeech::ErrorReason>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->localeChanged((*reinterpret_cast<std::add_pointer_t<QLocale>>(_a[1]))); break;
        case 4: _t->rateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->pitchChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->volumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 7: _t->voiceChanged((*reinterpret_cast<std::add_pointer_t<QVoice>>(_a[1]))); break;
        case 8: _t->sayingWord((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[4]))); break;
        case 9: _t->aboutToSynthesize((*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[1]))); break;
        case 10: _t->say((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: { qsizetype _r = _t->enqueue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qsizetype*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->stop((*reinterpret_cast<std::add_pointer_t<QTextToSpeech::BoundaryHint>>(_a[1]))); break;
        case 13: _t->stop(); break;
        case 14: _t->pause((*reinterpret_cast<std::add_pointer_t<QTextToSpeech::BoundaryHint>>(_a[1]))); break;
        case 15: _t->pause(); break;
        case 16: _t->resume(); break;
        case 17: _t->setLocale((*reinterpret_cast<std::add_pointer_t<QLocale>>(_a[1]))); break;
        case 18: _t->setRate((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 19: _t->setPitch((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 20: _t->setVolume((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 21: _t->setVoice((*reinterpret_cast<std::add_pointer_t<QVoice>>(_a[1]))); break;
        case 22: { bool _r = _t->setEngine((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->setEngine((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { QTextToSpeech::ErrorReason _r = _t->errorReason();
            if (_a[0]) *reinterpret_cast<QTextToSpeech::ErrorReason*>(_a[0]) = std::move(_r); }  break;
        case 25: { QString _r = _t->errorString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 26: { QList<QLocale> _r = _t->availableLocales();
            if (_a[0]) *reinterpret_cast<QList<QLocale>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QList<QVoice> _r = _t->availableVoices();
            if (_a[0]) *reinterpret_cast<QList<QVoice>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QStringList _r = _t->availableEngines();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QVoice >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QVoice >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeech::*)(const QString & )>(_a, &QTextToSpeech::engineChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeech::*)(QTextToSpeech::State )>(_a, &QTextToSpeech::stateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeech::*)(QTextToSpeech::ErrorReason , const QString & )>(_a, &QTextToSpeech::errorOccurred, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeech::*)(const QLocale & )>(_a, &QTextToSpeech::localeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeech::*)(double )>(_a, &QTextToSpeech::rateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeech::*)(double )>(_a, &QTextToSpeech::pitchChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeech::*)(double )>(_a, &QTextToSpeech::volumeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeech::*)(const QVoice & )>(_a, &QTextToSpeech::voiceChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeech::*)(const QString & , qsizetype , qsizetype , qsizetype )>(_a, &QTextToSpeech::sayingWord, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QTextToSpeech::*)(qsizetype )>(_a, &QTextToSpeech::aboutToSynthesize, 9))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVoice >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->engine(); break;
        case 1: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->volume(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->rate(); break;
        case 4: *reinterpret_cast<double*>(_v) = _t->pitch(); break;
        case 5: *reinterpret_cast<QLocale*>(_v) = _t->locale(); break;
        case 6: *reinterpret_cast<QVoice*>(_v) = _t->voice(); break;
        case 7: QtMocHelpers::assignFlags<Capabilities>(_v, _t->engineCapabilities()); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEngine(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setVolume(*reinterpret_cast<double*>(_v)); break;
        case 3: _t->setRate(*reinterpret_cast<double*>(_v)); break;
        case 4: _t->setPitch(*reinterpret_cast<double*>(_v)); break;
        case 5: _t->setLocale(*reinterpret_cast<QLocale*>(_v)); break;
        case 6: _t->setVoice(*reinterpret_cast<QVoice*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QTextToSpeech::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QTextToSpeech::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QTextToSpeechE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QTextToSpeech::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void QTextToSpeech::engineChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QTextToSpeech::stateChanged(QTextToSpeech::State _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QTextToSpeech::errorOccurred(QTextToSpeech::ErrorReason _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void QTextToSpeech::localeChanged(const QLocale & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QTextToSpeech::rateChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QTextToSpeech::pitchChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QTextToSpeech::volumeChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void QTextToSpeech::voiceChanged(const QVoice & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void QTextToSpeech::sayingWord(const QString & _t1, qsizetype _t2, qsizetype _t3, qsizetype _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 9
void QTextToSpeech::aboutToSynthesize(qsizetype _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
